package calls

import (
	"encoding/json"
	"fmt"
	"log"
	"net/http"
	"os"

	b "streifling.com/jason/cpolis/cmd/backend"
)

func ServePDFList(c *b.Config) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		if !tokenIsVerified(w, r, c) {
			return
		}

		files, err := os.ReadDir(c.PDFDir)
		if err != nil {
			log.Println(err)
			http.Error(w, err.Error(), http.StatusInternalServerError)
			return
		}

		fileNames := make([]string, 0)
		for _, file := range files {
			fileNames = append(fileNames, file.Name())
		}

		w.Header().Set("Content-Type", "application/json")
		if err = json.NewEncoder(w).Encode(fileNames); err != nil {
			log.Println(err)
			http.Error(w, err.Error(), http.StatusInternalServerError)
			return
		}
	}
}

func ServePDF(c *b.Config) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		if !tokenIsVerified(w, r, c) {
			return
		}

		http.ServeFile(w, r, fmt.Sprint(c.PDFDir, "/", r.PathValue("id")))
	}
}
